summaryrefslogtreecommitdiffstats
path: root/kde.py
diff options
context:
space:
mode:
Diffstat (limited to 'kde.py')
-rw-r--r--kde.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/kde.py b/kde.py
index 783f727..b4bcf3b 100644
--- a/kde.py
+++ b/kde.py
@@ -14,8 +14,8 @@ NORMAL ="\033[0m"
import os, re
# Returns the name of the shared object (i.e. libkdeui.so.4)
# referenced by a libtool archive (like libkdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()
match = re.search("^dlname='([^']*)'$", contents, re.M)
@@ -82,8 +82,8 @@ def detect_kde(env):
print GREEN+"qt is in "+qtdir+NORMAL
else:
libdir = os.popen('kde-config --expandvars --install lib').read().strip()
- libkdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libkdeui.la')
- m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libqt').read().strip().split()[2])
+ libtdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libtdeui.la')
+ m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libqt').read().strip().split()[2])
if m:
qtdir = m.group(1)
print YELLOW+"qt was found as "+m.group(1)+NORMAL
@@ -14,8 +14,8 @@ NORMAL ="\033[0m"
import os, re
-# Returns the name of the shared object (i.e. libkdeui.so.4)
-# referenced by a libtool archive (like libkdeui.la)
+# Returns the name of the shared object (i.e. libtdeui.so.4)
+# referenced by a libtool archive (like libtdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()